==> ejc-budgetmanage-impl-3.0.0-20220401.121145-44-sources.jar: com/ejianc/business/record/bean/RecordContrastanalysisdetailEntity.java <==
package com.ejianc.business.record.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 对比分析变更记录子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_record_budgetmanage_contrastanalysisdetail")
public class RecordContrastanalysisdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="code")
    private java.lang.String code; // 清单编码
    @TableField(value="name")
    private java.lang.String name; // 工程名称或费用名称
    @TableField(value="bidding_stage")
    private java.math.BigDecimal biddingStage; // 投标阶段
    @TableField(value="quata_design_total")
    private java.math.BigDecimal quataDesignTotal; // 限额设计阶段
    @TableField(value="design_buget_estimate")
    private java.math.BigDecimal designBugetEstimate; // 设计概算阶段
    @TableField(value="construction_buget_estimate")
    private java.math.BigDecimal constructionBugetEstimate; // 施工图预算阶段
    @TableField(value="tender_list_total")
    private java.math.BigDecimal tenderListTotal; // 投标清单合价
    @TableField(value="tender_list_price")
    private java.math.BigDecimal tenderListPrice; // 投标清单单价
    @TableField(value="quota_design_budget_total")
    private java.math.BigDecimal quotaDesignBudgetTotal; // 限额设计预算合价
    @TableField(value="quota_design_budget_price")
    private java.math.BigDecimal quotaDesignBudgetPrice; // 限额设计预算单价
    @TableField(value="design_buget_estimate_total")
    private java.math.BigDecimal designBugetEstimateTotal; // 设计概算合价
    @TableField(value="design_buget_estimate_price")
    private java.math.BigDecimal designBugetEstimatePrice; // 设计概算单价
    @TableField(value="construction_buget_estimate_total")
    private java.math.BigDecimal constructionBugetEstimateTotal; // 施工图预算合价
    @TableField(value="construction_buget_estimate_price")
    private java.math.BigDecimal constructionBugetEstimatePrice; // 施工图预算单价
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="tid")
    private java.lang.String tid; // 表格行id
    @TableField(value="tpid")
    private java.lang.String tpid; // 表格行父id
    
    
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 清单编码
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 清单编码
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }
    /**
     * 工程名称或费用名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 工程名称或费用名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 投标阶段
     */
    public java.math.BigDecimal getBiddingStage() {
        return biddingStage;
    }

    /**
     * 投标阶段
     */
    public void setBiddingStage(java.math.BigDecimal biddingStage) {
        this.biddingStage = biddingStage;
    }
    /**
     * 限额设计阶段
     */
    public java.math.BigDecimal getQuataDesignTotal() {
        return quataDesignTotal;
    }

    /**
     * 限额设计阶段
     */
    public void setQuataDesignTotal(java.math.BigDecimal quataDesignTotal) {
        this.quataDesignTotal = quataDesignTotal;
    }
    /**
     * 设计概算阶段
     */
    public java.math.BigDecimal getDesignBugetEstimate() {
        return designBugetEstimate;
    }

    /**
     * 设计概算阶段
     */
    public void setDesignBugetEstimate(java.math.BigDecimal designBugetEstimate) {
        this.designBugetEstimate = designBugetEstimate;
    }
    /**
     * 施工图预算阶段
     */
    public java.math.BigDecimal getConstructionBugetEstimate() {
        return constructionBugetEstimate;
    }

    /**
     * 施工图预算阶段
     */
    public void setConstructionBugetEstimate(java.math.BigDecimal constructionBugetEstimate) {
        this.constructionBugetEstimate = constructionBugetEstimate;
    }
    /**
     * 投标清单合价
     */
    public java.math.BigDecimal getTenderListTotal() {
        return tenderListTotal;
    }

    /**
     * 投标清单合价
     */
    public void setTenderListTotal(java.math.BigDecimal tenderListTotal) {
        this.tenderListTotal = tenderListTotal;
    }
    /**
     * 投标清单单价
     */
    public java.math.BigDecimal getTenderListPrice() {
        return tenderListPrice;
    }

    /**
     * 投标清单单价
     */
    public void setTenderListPrice(java.math.BigDecimal tenderListPrice) {
        this.tenderListPrice = tenderListPrice;
    }
    /**
     * 限额设计预算合价
     */
    public java.math.BigDecimal getQuotaDesignBudgetTotal() {
        return quotaDesignBudgetTotal;
    }

    /**
     * 限额设计预算合价
     */
    public void setQuotaDesignBudgetTotal(java.math.BigDecimal quotaDesignBudgetTotal) {
        this.quotaDesignBudgetTotal = quotaDesignBudgetTotal;
    }
    /**
     * 限额设计预算单价
     */
    public java.math.BigDecimal getQuotaDesignBudgetPrice() {
        return quotaDesignBudgetPrice;
    }

    /**
     * 限额设计预算单价
     */
    public void setQuotaDesignBudgetPrice(java.math.BigDecimal quotaDesignBudgetPrice) {
        this.quotaDesignBudgetPrice = quotaDesignBudgetPrice;
    }
    /**
     * 设计概算合价
     */
    public java.math.BigDecimal getDesignBugetEstimateTotal() {
        return designBugetEstimateTotal;
    }

    /**
     * 设计概算合价
     */
    public void setDesignBugetEstimateTotal(java.math.BigDecimal designBugetEstimateTotal) {
        this.designBugetEstimateTotal = designBugetEstimateTotal;
    }
    /**
     * 设计概算单价
     */
    public java.math.BigDecimal getDesignBugetEstimatePrice() {
        return designBugetEstimatePrice;
    }

    /**
     * 设计概算单价
     */
    public void setDesignBugetEstimatePrice(java.math.BigDecimal designBugetEstimatePrice) {
        this.designBugetEstimatePrice = designBugetEstimatePrice;
    }
    /**
     * 施工图预算合价
     */
    public java.math.BigDecimal getConstructionBugetEstimateTotal() {
        return constructionBugetEstimateTotal;
    }

    /**
     * 施工图预算合价
     */
    public void setConstructionBugetEstimateTotal(java.math.BigDecimal constructionBugetEstimateTotal) {
        this.constructionBugetEstimateTotal = constructionBugetEstimateTotal;
    }
    /**
     * 施工图预算单价
     */
    public java.math.BigDecimal getConstructionBugetEstimatePrice() {
        return constructionBugetEstimatePrice;
    }

    /**
     * 施工图预算单价
     */
    public void setConstructionBugetEstimatePrice(java.math.BigDecimal constructionBugetEstimatePrice) {
        this.constructionBugetEstimatePrice = constructionBugetEstimatePrice;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 表格行id
     */
    public java.lang.String getTid() {
        return tid;
    }

    /**
     * 表格行id
     */
    public void setTid(java.lang.String tid) {
        this.tid = tid;
    }
    /**
     * 表格行父id
     */
    public java.lang.String getTpid() {
        return tpid;
    }

    /**
     * 表格行父id
     */
    public void setTpid(java.lang.String tpid) {
        this.tpid = tpid;
    }
    
}

==> ejc-budgetmanage-impl-3.0.0-20240528.015635-206-sources.jar: com/ejianc/business/record/bean/RecordContrastanalysisdetailEntity.java <==
package com.ejianc.business.record.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 对比分析变更记录子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_record_budgetmanage_contrastanalysisdetail")
public class RecordContrastanalysisdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="original_id")
    private java.lang.Long originalId; // 原始单据id（对比分析表子表）
    @TableField(value="sort")
    private java.lang.String sort; // 序号
    @TableField(value="code")
    private java.lang.String code; // 清单编码
    @TableField(value="name")
    private java.lang.String name; // 工程名称或费用名称
    @TableField(value="bidding_stage")
    private java.math.BigDecimal biddingStage; // 投标阶段
    @TableField(value="quata_design_total")
    private java.math.BigDecimal quataDesignTotal; // 限额设计阶段
    @TableField(value="design_buget_estimate")
    private java.math.BigDecimal designBugetEstimate; // 设计概算阶段
    @TableField(value="construction_buget_estimate")
    private java.math.BigDecimal constructionBugetEstimate; // 施工图预算阶段
    @TableField(value="tender_list_total")
    private java.math.BigDecimal tenderListTotal; // 投标清单合价
    @TableField(value="tender_list_price")
    private java.math.BigDecimal tenderListPrice; // 投标清单单价
    @TableField(value="quota_design_budget_total")
    private java.math.BigDecimal quotaDesignBudgetTotal; // 限额设计预算合价
    @TableField(value="quota_design_budget_price")
    private java.math.BigDecimal quotaDesignBudgetPrice; // 限额设计预算单价
    @TableField(value="design_buget_estimate_total")
    private java.math.BigDecimal designBugetEstimateTotal; // 设计概算合价
    @TableField(value="design_buget_estimate_price")
    private java.math.BigDecimal designBugetEstimatePrice; // 设计概算单价
    @TableField(value="construction_buget_estimate_total")
    private java.math.BigDecimal constructionBugetEstimateTotal; // 施工图预算合价
    @TableField(value="construction_buget_estimate_price")
    private java.math.BigDecimal constructionBugetEstimatePrice; // 施工图预算单价
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="tid")
    private java.lang.String tid; // 表格行id
    @TableField(value="tpid")
    private java.lang.String tpid; // 表格行父id
    @TableField(value="innercode")
    private String innercode; // 内码
    
    
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 清单编码
     */
    public java.lang.String getCode() {
        return code;
    }

    /**
     * 清单编码
     */
    public void setCode(java.lang.String code) {
        this.code = code;
    }
    /**
     * 工程名称或费用名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 工程名称或费用名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 投标阶段
     */
    public java.math.BigDecimal getBiddingStage() {
        return biddingStage;
    }

    /**
     * 投标阶段
     */
    public void setBiddingStage(java.math.BigDecimal biddingStage) {
        this.biddingStage = biddingStage;
    }
    /**
     * 限额设计阶段
     */
    public java.math.BigDecimal getQuataDesignTotal() {
        return quataDesignTotal;
    }

    /**
     * 限额设计阶段
     */
    public void setQuataDesignTotal(java.math.BigDecimal quataDesignTotal) {
        this.quataDesignTotal = quataDesignTotal;
    }
    /**
     * 设计概算阶段
     */
    public java.math.BigDecimal getDesignBugetEstimate() {
        return designBugetEstimate;
    }

    /**
     * 设计概算阶段
     */
    public void setDesignBugetEstimate(java.math.BigDecimal designBugetEstimate) {
        this.designBugetEstimate = designBugetEstimate;
    }
    /**
     * 施工图预算阶段
     */
    public java.math.BigDecimal getConstructionBugetEstimate() {
        return constructionBugetEstimate;
    }

    /**
     * 施工图预算阶段
     */
    public void setConstructionBugetEstimate(java.math.BigDecimal constructionBugetEstimate) {
        this.constructionBugetEstimate = constructionBugetEstimate;
    }
    /**
     * 投标清单合价
     */
    public java.math.BigDecimal getTenderListTotal() {
        return tenderListTotal;
    }

    /**
     * 投标清单合价
     */
    public void setTenderListTotal(java.math.BigDecimal tenderListTotal) {
        this.tenderListTotal = tenderListTotal;
    }
    /**
     * 投标清单单价
     */
    public java.math.BigDecimal getTenderListPrice() {
        return tenderListPrice;
    }

    /**
     * 投标清单单价
     */
    public void setTenderListPrice(java.math.BigDecimal tenderListPrice) {
        this.tenderListPrice = tenderListPrice;
    }
    /**
     * 限额设计预算合价
     */
    public java.math.BigDecimal getQuotaDesignBudgetTotal() {
        return quotaDesignBudgetTotal;
    }

    /**
     * 限额设计预算合价
     */
    public void setQuotaDesignBudgetTotal(java.math.BigDecimal quotaDesignBudgetTotal) {
        this.quotaDesignBudgetTotal = quotaDesignBudgetTotal;
    }
    /**
     * 限额设计预算单价
     */
    public java.math.BigDecimal getQuotaDesignBudgetPrice() {
        return quotaDesignBudgetPrice;
    }

    /**
     * 限额设计预算单价
     */
    public void setQuotaDesignBudgetPrice(java.math.BigDecimal quotaDesignBudgetPrice) {
        this.quotaDesignBudgetPrice = quotaDesignBudgetPrice;
    }
    /**
     * 设计概算合价
     */
    public java.math.BigDecimal getDesignBugetEstimateTotal() {
        return designBugetEstimateTotal;
    }

    /**
     * 设计概算合价
     */
    public void setDesignBugetEstimateTotal(java.math.BigDecimal designBugetEstimateTotal) {
        this.designBugetEstimateTotal = designBugetEstimateTotal;
    }
    /**
     * 设计概算单价
     */
    public java.math.BigDecimal getDesignBugetEstimatePrice() {
        return designBugetEstimatePrice;
    }

    /**
     * 设计概算单价
     */
    public void setDesignBugetEstimatePrice(java.math.BigDecimal designBugetEstimatePrice) {
        this.designBugetEstimatePrice = designBugetEstimatePrice;
    }
    /**
     * 施工图预算合价
     */
    public java.math.BigDecimal getConstructionBugetEstimateTotal() {
        return constructionBugetEstimateTotal;
    }

    /**
     * 施工图预算合价
     */
    public void setConstructionBugetEstimateTotal(java.math.BigDecimal constructionBugetEstimateTotal) {
        this.constructionBugetEstimateTotal = constructionBugetEstimateTotal;
    }
    /**
     * 施工图预算单价
     */
    public java.math.BigDecimal getConstructionBugetEstimatePrice() {
        return constructionBugetEstimatePrice;
    }

    /**
     * 施工图预算单价
     */
    public void setConstructionBugetEstimatePrice(java.math.BigDecimal constructionBugetEstimatePrice) {
        this.constructionBugetEstimatePrice = constructionBugetEstimatePrice;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 表格行id
     */
    public java.lang.String getTid() {
        return tid;
    }

    /**
     * 表格行id
     */
    public void setTid(java.lang.String tid) {
        this.tid = tid;
    }
    /**
     * 表格行父id
     */
    public java.lang.String getTpid() {
        return tpid;
    }

    /**
     * 表格行父id
     */
    public void setTpid(java.lang.String tpid) {
        this.tpid = tpid;
    }

    public String getInnercode() {
        return innercode;
    }

    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }

    public Long getOriginalId() {
        return originalId;
    }

    public void setOriginalId(Long originalId) {
        this.originalId = originalId;
    }
}
